@@ -24,7 +24,7 @@
 
 #include <gst/gst.h>
 
-#include <Lum/OS/Thread.h>
+#include <Lum/OS/Color.h>
 
 #include <Lum/OS/X11/SubWindow.h>
 
@@ -52,6 +52,8 @@ private:
   Lum::Model::ActionRef knipsed;      //! If triggered an has been catched
   Lum::Model::ActionRef timer;        //! Timer to periodically check the camera orientation
 
+  Lum::OS::ColorRef     greenColor;
+
 private:
   void CheckCameraOrientation();
 
@@ -68,6 +70,8 @@ public:
 
   void CalcSize();
   void Layout();
+  void Draw(Lum::OS::DrawInfo* draw,
+            int x, int y, size_t w, size_t h);
 
   void RequestImage();
   void CancelRequestImage();
